@@ -1,7 +1,8 @@
+# Reading in combined code & documentation, and showing help
 # Work out where this file lives!
 
-textfilename <- attr( pos.to.env( which( search()=='package:mvbutils')), 'path')
-textfilename <- file.path( textfilename, 'demo', 'original.dochelp.rrr')
+textfilename <- attr( as.environment( 'package:mvbutils'), 'path')
+textfilename <- file.path( textfilename, 'demostuff', 'original.dochelp.rrr')
 
 original.dochelp <- source.mvb( textfilename)
 
